# Contributing to Econ-ARK

### Welcome!

Thank you for considering contributing to Econ-ARK!  We're a young project with a small but committed community that's hoping to grow while maintaining our friendly and responsive culture.  Whether you're an economist or a technologist, a writer or a coder, an undergrad or a full professor, a professional or a hobbyist, there's a place for you in the Econ-ARK community. 

We're still creating our contribution infrastructure, so this document is a work in progress.  If you have any questions please feel free to @ or otherwise reach out project manager [Shauna](https://github.com/shaunagm), or lead developers [Chris](https://github.com/llorracc) and [Matt](https://github.com/mnwhite).  If you prefer to connect through email, you can send it to __econ-ark at jhuecon dot org__.

### How to Contribute

We're open to all kinds of contributions, from bug reports to help with our docs to suggestions on how to improve our code.  The best way to figure out if the contribution you'd like to make is something we'd merge or otherwise accept, is to open up an issue in our issue tracker.  Please create an issue rather than immediately submitting pull request, unless the change you'd like to make is so minor you won't mind if the pull request is rejected.  For bigger contributions, we want to proactively talk things through so we don't end up wasting your time.

While we're thrilled to receive all kinds of contributions, there are a few key areas we'd especially like help with:

* porting existing heterogenous agent/agent based models into HARK
* curating and expanding the collection of projects which use Econ-ARK (which we store in the [remark](https://github.com/econ-ark/REMARK) repository)
* creating demonstrations of how to use Econ-ARK (which we store in the [DemARK](https://github.com/econ-ark/DemARK) repository)
* expanding test coverage of our existing code

If you'd like to help with those or any other kind of contribution, reach out to us and we'll help you do so.  

We don't currently have guidelines for opening issues or pull requests, so include as much information as seems relevant to you, and we'll ask you if we need to know more.

### Responding to Issues & Pull Requests

We're trying to get better at managing our open issues and pull requests.  We've created a new set of goals for all issues and pull requests in our Econ-ARK repos:

1. Initial response within one or two days.
2. Substantive response within two weeks.
3. Resolution of issue/pull request within three months.  

If you've been waiting on us for more than two weeks for any reason, please feel free to give us a nudge.  Correspondingly, we ask that you respond to any questions or requests from us within two weeks as well, even if it's just to say, "Sorry, I can't get to this for a while yet". If we don't hear back from you, we may close your issue or pull request.  If you want to re-open it, just ask - we're glad to do so.

### Getting Started

The [quick start guide](https://github.com/econ-ark/HARK#ii-quick-start-guide) in our README provides instructions for how to get started running HARK.  This also serves as a setup guide for new contributors.  If you run into any problems, please let us know by opening an issue in the issue tracker.

Thanks again!  We're so glad to have you in our community.
